@@ -180,6 +180,8 @@ add_dialog_key_press (GtkWidget    *widget,
 }
 
 
+/*  ja:追加ダイアログ表示
+    mmaid,ウインドウ情報                                                    */
 void
 add_dialog (MmaidWindow *mmaid)
 {
@@ -215,26 +217,26 @@ add_dialog (MmaidWindow *mmaid)
   for (i = 0; i < count; i++)
     {
       id3tag = mm_list_get_nth (MM_LIST (mmaid->list), i);
-      if (id3tag->title   && g_list_find_custom (glist1, id3tag->title,
-                                                (GCompareFunc)strcmp) == NULL)
+      if (id3tag->title   && !g_list_find_custom (glist1, id3tag->title,
+                                                        (GCompareFunc)strcmp))
         glist1 = g_list_insert_sorted (glist1, g_strdup (id3tag->title),
-                                                (GCompareFunc)strcmp);
-      if (id3tag->artist  && g_list_find_custom (glist2, id3tag->artist,
-                                                (GCompareFunc)strcmp) == NULL)
+                                                        (GCompareFunc)strcmp);
+      if (id3tag->artist  && !g_list_find_custom (glist2, id3tag->artist,
+                                                        (GCompareFunc)strcmp))
         glist2 = g_list_insert_sorted (glist2, g_strdup (id3tag->artist),
-                                                (GCompareFunc)strcmp);
-      if (id3tag->album   && g_list_find_custom (glist3, id3tag->album,
-                                                (GCompareFunc)strcmp) == NULL)
+                                                        (GCompareFunc)strcmp);
+      if (id3tag->album   && !g_list_find_custom (glist3, id3tag->album,
+                                                        (GCompareFunc)strcmp))
         glist3 = g_list_insert_sorted (glist3, g_strdup (id3tag->album),
-                                                (GCompareFunc)strcmp);
-      if (id3tag->comment && g_list_find_custom (glist5, id3tag->comment,
-                                                (GCompareFunc)strcmp) == NULL)
+                                                        (GCompareFunc)strcmp);
+      if (id3tag->comment && !g_list_find_custom (glist5, id3tag->comment,
+                                                        (GCompareFunc)strcmp))
         glist5 = g_list_insert_sorted (glist5, g_strdup (id3tag->comment),
-                                                (GCompareFunc)strcmp);
+                                                        (GCompareFunc)strcmp);
     }
   for (i = 0; i < 256; i++)
-    if (genre[0][i] && g_list_find_custom (glist7, genre[0][i],
-                                                (GCompareFunc)strcmp) == NULL)
+    if (genre[0][i] && !g_list_find_custom (glist7, genre[0][i],
+                                                        (GCompareFunc)strcmp))
       glist7 = g_list_append (glist7, g_strdup (genre[0][i]));
   charset = g_strsplit (charset_list, ",", G_MAXINT);
   for (i = 0; charset[i]; i++)
