@@ -232,6 +232,8 @@ edit_dialog_key_press (GtkWidget   *widget,
 }
 
 
+/*  ja:編集ダイアログ表示
+    mmaid,ウインドウ情報                                                    */
 void
 edit_dialog (MmaidWindow *mmaid)
 {
@@ -271,26 +273,26 @@ edit_dialog (MmaidWindow *mmaid)
   for (i = 0; i < count; i++)
     {
       id3tag = mm_list_get_nth (MM_LIST (mmaid->list), i);
-      if (id3tag->title   && g_list_find_custom (glist1, id3tag->title,
-                                                (GCompareFunc)strcmp) == NULL)
+      if (id3tag->title   && !g_list_find_custom (glist1, id3tag->title,
+                                                        (GCompareFunc)strcmp))
         glist1 = g_list_insert_sorted (glist1, g_strdup (id3tag->title),
-                                                (GCompareFunc)strcmp);
-      if (id3tag->artist  && g_list_find_custom (glist2, id3tag->artist,
-                                                (GCompareFunc)strcmp) == NULL)
+                                                        (GCompareFunc)strcmp);
+      if (id3tag->artist  && !g_list_find_custom (glist2, id3tag->artist,
+                                                        (GCompareFunc)strcmp))
         glist2 = g_list_insert_sorted (glist2, g_strdup (id3tag->artist),
-                                                (GCompareFunc)strcmp);
-      if (id3tag->album   && g_list_find_custom (glist3, id3tag->album,
-                                                (GCompareFunc)strcmp) == NULL)
+                                                        (GCompareFunc)strcmp);
+      if (id3tag->album   && !g_list_find_custom (glist3, id3tag->album,
+                                                        (GCompareFunc)strcmp))
         glist3 = g_list_insert_sorted (glist3, g_strdup (id3tag->album),
-                                                (GCompareFunc)strcmp);
-      if (id3tag->comment && g_list_find_custom (glist5, id3tag->comment,
-                                                (GCompareFunc)strcmp) == NULL)
+                                                        (GCompareFunc)strcmp);
+      if (id3tag->comment && !g_list_find_custom (glist5, id3tag->comment,
+                                                        (GCompareFunc)strcmp))
         glist5 = g_list_insert_sorted (glist5, g_strdup (id3tag->comment),
-                                                (GCompareFunc)strcmp);
+                                                        (GCompareFunc)strcmp);
     }
   for (i = 0; i < 256; i++)
-    if (genre[0][i] && g_list_find_custom (glist7, genre[0][i],
-                                                (GCompareFunc)strcmp) == NULL)
+    if (genre[0][i] && !g_list_find_custom (glist7, genre[0][i],
+                                                        (GCompareFunc)strcmp))
       glist7 = g_list_append (glist7, g_strdup (genre[0][i]));
   charset = g_strsplit (charset_list, ",", G_MAXINT);
   for (i = 0; charset[i]; i++)
@@ -365,17 +367,17 @@ edit_dialog (MmaidWindow *mmaid)
 
             id3tag0 = mm_list_get_nth (MM_LIST (mmaid->list), i);
             t = t && id3tag0->title
-                        && g_strcmp (id3tag->title,   id3tag0->title) == 0;
+                            && !g_strcmp (id3tag->title,   id3tag0->title);
             a = a && id3tag0->artist
-                        && g_strcmp (id3tag->artist,  id3tag0->artist) == 0;
+                            && !g_strcmp (id3tag->artist,  id3tag0->artist);
             l = l && id3tag0->album
-                        && g_strcmp (id3tag->album,   id3tag0->album) == 0;
+                            && !g_strcmp (id3tag->album,   id3tag0->album);
             c = c && id3tag0->comment
-                        && g_strcmp (id3tag->comment, id3tag0->comment) == 0;
+                            && !g_strcmp (id3tag->comment, id3tag0->comment);
             g = g && id3tag0->genre
-                        && g_strcmp (id3tag->genre,   id3tag0->genre) == 0;
+                            && !g_strcmp (id3tag->genre,   id3tag0->genre);
             e = e && id3tag0->charset
-                        && g_strcmp (id3tag->charset, id3tag0->charset) == 0;
+                            && !g_strcmp (id3tag->charset, id3tag0->charset);
           }
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo1)->entry),
                                                     t ? id3tag->title   : "");
