@@ -128,9 +128,6 @@ set_menu_bar (MmaidWindow *mmaid)
       gtk_widget_set_sensitive (toolbar_items[13].item, TRUE);
       gtk_widget_set_sensitive (toolbar_items[15].item, arrow_up);
       gtk_widget_set_sensitive (toolbar_items[16].item, arrow_down);
-#ifdef G_OS_WIN32
-      gtk_widget_set_sensitive (toolbar_items[18].item, TRUE);
-#endif /* G_OS_WIN32 */
     }
   else
     {
@@ -159,9 +156,6 @@ set_menu_bar (MmaidWindow *mmaid)
       gtk_widget_set_sensitive (toolbar_items[13].item, FALSE);
       gtk_widget_set_sensitive (toolbar_items[15].item, FALSE);
       gtk_widget_set_sensitive (toolbar_items[16].item, FALSE);
-#ifdef G_OS_WIN32
-      gtk_widget_set_sensitive (toolbar_items[18].item, FALSE);
-#endif /* G_OS_WIN32 */
     }
   menu = gtk_item_factory_get_widget (ifactory_menu, "<main>/Window");
   glist = gtk_container_children (GTK_CONTAINER (menu));
