@@ -366,8 +366,6 @@ mm_list_init (MmList *list)
                                 G_TYPE_BOOLEAN, /* MM_LIST_DELETE_VISIBLE */
                                 G_TYPE_BOOLEAN, /* MM_LIST_DELETE_SENSITIVE */
                                 G_TYPE_BOOLEAN);/* MM_LIST_DELETE_TOGGLE */
-  gtk_tree_sortable_set_default_sort_func (GTK_TREE_SORTABLE (list->store),
-                                (GtkTreeIterCompareFunc)gtk_false, NULL, NULL);
   gtk_tree_view_set_model (GTK_TREE_VIEW (list), GTK_TREE_MODEL (list->store));
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (list), FALSE);
   for (i = 0; i < 9; i++)
@@ -748,7 +746,6 @@ mm_list_swap (MmList     *list,
   gboolean refresh_visible1, refresh_sensitive1, refresh_toggle1;
   gboolean delete_visible1, delete_sensitive1, delete_toggle1;
   gchar *track0, *track1, *status0, *status1;
-  gint n, c;
   GtkTreeIter iter0, iter1;
   GtkTreeSelection *select;
   ID3Tag *id3tag0, *id3tag1;
@@ -757,11 +754,6 @@ mm_list_swap (MmList     *list,
                                                             &iter0, NULL, n0);
   gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list->store),
                                                             &iter1, NULL, n1);
-  mm_list_get_cursor (list, &n, &c);
-  if (n == n0)
-    mm_list_set_cursor (list, n1, c);
-  if (n == n1)
-    mm_list_set_cursor (list, n0, c);
   select = gtk_tree_view_get_selection (GTK_TREE_VIEW (list));
   selected0 = gtk_tree_selection_iter_is_selected (select, &iter0);
   selected1 = gtk_tree_selection_iter_is_selected (select, &iter1);
@@ -1044,16 +1036,6 @@ mm_list_set_cursor (MmList     *list,
 }
 
 
-/*  ja:ソートしない
-    list,ウィジェット                                                       */
-void
-mm_list_sort_off (MmList *list)
-{
-  gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list->store),
-                GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
-}
-
-
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
